/**
 * @file pcm_in.h
 * Pulse Code Modulated audio input
 * @author Marko Mkel <marko.makela at iki.fi>
 */

/* Copyright  2004 Marko Mkel.

   This file is part of C2N, a program for processing data tapes in
   Commodore C2N format and other formats.

   C2N is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   C2N is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
   or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
   License for more details.

   The GNU General Public License is often shipped with GNU software, and
   is generally kept in a file called COPYING or LICENSE.  If you do not
   have a copy of the license, write to the Free Software Foundation,
   59 Temple Place, Suite 330, Boston, MA 02111 USA. */

/** Initialize the PCM audio decoder
 * @param f		the input stream
 * @param bias		DC level of the input (normally 128)
 * @param threshold	hysteresis threshold for detecting transitions
 */
void
pcm_in_init (FILE* f,
	     int bias,
	     int threshold);

/** Clean up the PCM audio decoder */
void
pcm_in_cleanup (void);

/** Find next PCM audio chunk
 * @return	zero on success, nonzero on failure
 */
int
pcm_in_next (void);

/** Extract a cycle from a PCM audio file
 * @return	the cycle width (unit: 8 s), 255 (pause) or EOF
 */
int
pcm_in_read (void);

/** Get the PCM file position
 * @return	byte offset from the beginning of the file
 */
long
pcm_in_pos (void);
