/**
 * @file pcm_out.h
 * Pulse Code Modulated audio output
 * @author Marko Mkel <marko.makela at iki.fi>
 */

/* Copyright  2002,2004 Marko Mkel.

   This file is part of C2N, a program for processing data tapes in
   Commodore C2N format and other formats.

   C2N is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   C2N is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
   or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
   License for more details.

   The GNU General Public License is often shipped with GNU software, and
   is generally kept in a file called COPYING or LICENSE.  If you do not
   have a copy of the license, write to the Free Software Foundation,
   59 Temple Place, Suite 330, Boston, MA 02111 USA. */

#include <stdio.h>

/** PCM sample types */
enum pcm_type
{
  eight,		/**< eight bits */
  lsb16,		/**< sixteen bits, least significant byte first */
  msb16,		/**< sixteen bits, most significant byte first */
  eight_,		/**< eight bits, inverted phase */
  lsb16_,		/**< sixteen bits, LSB first, inverted phase */
  msb16_		/**< sixteen bits, MSB first, inverted phase */
};

/** sample rate in Hz (0 if PCM subsystem disabled) */
extern unsigned samplerate;

/** Set up the PCM resources
 * @param out		output file handle (NULL=use stdout)
 * @param format	selected PCM sample format
 * @param channels	number of channels (1=mono, 2=stereo)
 * @param riff		flag: nonzero=output in RIFF WAVE format
 * @param sign		flag: nonzero=signed output, 0=unsigned
 * @param 
 */
void
pcm_init (FILE* out,
	  enum pcm_type format,
	  unsigned channels,
	  int riff,
	  int sign);

/** Compute the PCM samples
 * @param t_short	short cycle time/8s
 * @param t_medium	medium cycle time/8s
 * @param t_long	long cycle time/8s
 * @return		zero on success, nonzero on failure
 */
int
pcm_compute_samples (unsigned t_short,
		     unsigned t_medium,
		     unsigned t_long);
/** Deallocate the PCM resources */
void
pcm_cleanup (void);

/** Write audio samples corresponding to a pulse to standard output
 * @param p	the pulse to be written
 */
void
p_write_pcm (enum pulse p);
